package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M35J0``,````$````__\``+@`````````0```````````````````````````
M````````````````````^`````X?N@X`M`G-(;@!3,TA5&AI<R!P<F]G<F%M
M(&-A;FYO="!B92!R=6X@:6X@1$]3(&UO9&4N#0T*)``````````#)82,1T3J
MWT=$ZM]'1.K?Q%CDWT5$ZM\H6^#?3$3JWRA;[M]%1.K?Q$RWWT-$ZM\\6.;?
M143JWT=$Z]\61.K?N&3NWT1$ZM]Q8N#?143JW_]"[-]&1.K?4FEC:$=$ZM\`
M``````````````````````````````!010``3`$$`"XP*T@``````````.``
M#P$+`08``#````"@````````(#H````0````0`````!````0````$```!```
M```````$``````````#@````$```AP`!``,``````!```!``````$```$```
M`````!```````````````-2?``!D`````,```-`1````````````````````
M```````````````P00``'```````````````````````````````````````
M````````````````````0```*`$`````````````````````````````````
M`"YT97AT````7"L````0````,````!```````````````````"```&`N<F1A
M=&$``,1E````0````'````!```````````````````!```!`+F1A=&$```!D
M!````+`````0````L```````````````````0```P"YR<W)C````T!$```#`
M````(````,```````````````````$```,``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%:^B$%``%9H)CE``&AL04``Z`HI``!0Z/XH``"#Q!!6:!0Y0`!H5$%``.CQ
M*```4.CE*```@\007L-5B^R![`@$``!35E=HL$%``.BH`0``B47\C87X^___
MQP0D``0``#/;4%/_%0A`0`"%P`^%3`$``/\U$+!``(MU"%;_%81`0`!9687`
M5G03:*!!0`#H\P$``%F+QEGI5P$``.@U*0``_S44L$``BSV,0$``B47X_W4,
M_]>#Q`R+\#OS#X0?`0``.!YU!;Z<04``.5W\=!-6_W7\Z/<H``!9A<!9#X3+
M````5NCM*```BE0P_UF+#1"P0``Z$74*2(@<!HI4!O_K[(M5^/]U"(U$$`$]
M``0```^-S0```%%6C87X^___:)1!0`!0_Q640$``Z/`G``!0Z/PG``"+,.CC
M)P``4.CI)P``@\0<4(V%^/O__U#HS2<``%#HV2<``%G_,/]64(/$#(7`=4CH
MM2<``%#HNR<``&:+0`999B4`\&8]`(!U+NB;)P``4.BG)P``BS!9C87X^___
M:@%0Z(0G``!0Z)`G``!9_S#_%H/$#(7`=!#_-12P0`!3_]=96>GZ_O__C87X
M^___4&B@04``Z+<```"-A?C[__]0_Q5$0$``@\0,ZQ+_=0AHH$%``.B8````
MBT4(65E?7EO)PU6+[(U%"%#_=0CH!````%E97<-5B^Q14U:+=0A7A?9T9HL=
M@$!``/_3@S@`=%F*#HO&A,ET"X#Y/70&BD@!0.OQ*\:)1?S_TXLPBSZ%_W0W
M_W7\_W4(5_\50$!``(/$#(7`=0F+1?R`/`<]=`6#Q@3KV/_3*S"+10S!_@*)
M,(M%_(U$!P'K`C/`7UY;R<-5B^Q148M%#(`X/74#_T4,4U97_W4,Z#4G``"+
M70B)1?B-1?Q04^A:____BS6`0$``B_B#Q`R%_W0B5^@0)P``.T7X60^"RP``
M`(M-#(H!B`='083`=?;I/`$``/_6BP`S_S/).0AT!H/`!$?K]CD-1+1``'1`
MZ!\F``!0Z#$F``"+&%F-!+T(````4/_6_S#H!28``%#H%R8``%G_,/]3!(/$
M#(O8_]:)&/_6@S@`=57IL0```,<%1+1```$```#HU24``%#HYR4``(L868T$
MO0@```!0Z+\E``!0Z-$E``!9_S#_$XO8687;671YB\?!X`)0_];_,%/_%7Q`
M0`"#Q`S_UHD8_]:+`(M="(-DN`0`B7W\B@.+^X3`=`H\/70&BD<!1^ORZ&XE
M``!0Z(`E``"+$(M%^"O[68E5"(U$!P)0Z%,E``!0Z&4E``!9_S"+10C_$%F+
M^%G_UHL`BTW\A?^)/(AU!8/(_^LN_]:+`(M-_(L$B(H+0X3)B`AT"(#Y/70#
M0.OOBU4,Q@`]0(H*B`A`0H3)=?8SP%]>6\G#BT0D!%:+\(O(B@"$P'07BQ40
ML$``BA(ZPG4#C7$!BD$!083`=?&+QE[#5HMT)`B%]G1O@#X`=&I6Z',E``"-
M1##_68L-$+!``#O&=A:*$3@0=05(.\9W]SO&=@DX$'0#2.OU.\9U"8H`.@%T
M-5'K-T@[QG8&BA`Z$73U*\:-2`*!^0`$``!V!#/`7L-`4%:^/+!``%;_%7A`
M0`"#Q`R+QE[#:)Q!0`#_%41`0`!97L-5B^R#["135E=J"%F^A$)``(U]W&AT
M0D``\Z5FI>@)`0``QP0D:$)``.C]````N[!!0`!3Z/(```"^7$)``%;HYP``
M`+]00D``5^C<````:$1"0`#HT@```&B@04``Z,@```!H.$)``.B^````:"Q"
M0`#HM````&@80D``Z*+\__^#Q"2%P'0)4%?H(OW__UE9:`1"0`#HB/S__X7`
M670-4&CX04``Z`;]__]966CH04``Z&S\__^%P%ET"U!3Z.[\__]96>M.:-1!
M0`#H4OS__X7`670$4%;KY&C,04``Z!TD``"_P$%``(U<!>A7Z`XD``!05U/_
M%71`0`"#Q!2%P'425^CX(P```\-05NB?_/__@\0,:+Q!0`!H=$)``.B-_/__
M65E?7EO)PU6+[%&-1?Q0_W4(Z/O[__]9A<!9=![_%8!`0`"+`(M-_(T,B(M1
M!(U!!(72B1%TU(O(Z_#)PZ$8L$``@_C_=25H7$)``.BN^___A<!9=`^*`(3`
M=`D\,'0%:@%8ZP(SP*,8L$``PS/`PU6+[(/L(+C@0D``5XOX4(E%X,=%Y-A"
M0`#'1>C(0D``QT7LP$)``,=%\*Q"0`#'1?2H0D``B7WXZ#`C``"%P%D/AL0`
M``"-1>!35HE%_%?H._O__XOP687V#X2#````5N@((P``A<!9='C_=0A6_Q6$
M0$``687`675SZ#@B``!0Z$HB``#_-12P0`"+..C;(@``5HO8Z-,B``#_=0@#
MV.C)(@``@\00C40#`E#H!B(``%#H&"(``%G_,/\75HOX_S44L$``_W4(:)1!
M0`!7_Q640$``5_]U^.A`^___@\0DZPO_=0A7Z#+[__]968-%_`2+1?R+.%>)
M??CH;B(``(7`60^'1O___UY;7\G#58OLN."```#H72(``(-E]`!35KNH0D``
M:+!!0`#'1=AD0T``QT7<4$%``,=%X)Q!0`")7>3'1<#X04``QT7$7$-``,=%
MR%1#0`#'1<Q,0T``QT702$-``(E=U,=%Z$!#0`#'1>PT0T``B5WPZ!'Z__^+
M\%F%]G0?5NCB(0``A<!9=!16Z&K^__]6_Q5$0$``65GI<@4``+X`!```5XEU
M^.@%(0``4.@7(0``BSA95NCV(```4.@((0``6?\P_Q=968U-^%%0_Q4`0$``
MZ!_^__^%P(E%^'4^C7WHBS=6Z'TA``"%P%EV'U;HE/G__X7`670+4/\51$!`
M`%F)1?B#QP2#??@`=-2#??@`=0G'1?@L0T``ZT2+=?B`/@!T/+\'`0``H61`
M0`"#.`%^#P^^!E=0_Q5H0$``65GK$8L-;$!```^^!HL)9HL$02/'A<!U`\8&
M7T:`/@!UR8U%P(E%_(M%_(LP5NCU(```A<!9#X:@````5N@(^?__B_!9A?8/
MA($```#H("```%#H+"```(LXZ!,@``!0Z!D@``!965!6Z`0@``!0Z!`@``!9
M_S#_5U"#Q`R%P'5-Z.P?``!0Z/(?``!FBT`&668E`/!F/0!`=3/HTA\``%#H
MWA\``(LX66H"5NC!'P``4.C-'P``6?\P_Q>#Q`R%P'4+5O\51$!``%F)1?2#
M1?P$@WWT``^$3/___X-]]``/A:D```"-1=B)1?R+1?R+,%;H,2```(7`60^&
MCP```.AM'P``4.AY'P``BSCH8!\``%#H9A\``%E94%;H41\``%#H71\``%G_
M,/]74(/$#(7`=4WH.1\``%#H/Q\``&:+0`999B4`\&8]`$!U,^@?'P``4.@K
M'P``BSA9:@)6Z`X?``!0Z!H?``!9_S#_%X/$#(7`=0M6_Q5$0$``68E%](-%
M_`2#??0`#X1=_____W7XZ)$?``#_=?2+^.B''P``OB1#0``#^%;H>A\``%,#
M^.AR'P``C;P'``0``.BP'@``4.C"'@``BQ"#Q!2)5?Q7Z)P>``!0Z*X>``!9
M_S"+1?S_$/]U^(E%_%:+-91`0`#_-1"P0`#_=?1H&$-``%#_UO]U_/\5<$!`
M`&C`0D``Z#7W__]0_Q5$0$``BWT(4/\WZ&7U__^#Q#2)10B%P'4%BP>)10CH
M3?O__X7`#X4I`@``Z"H>``!0Z#8>``"+.,<$)`"```#_=0CH$QX``%#H'QX`
M`%G_,/]7/(/$#(E%"(7`#X3S`0``Z/0=``!0Z``>``!9BSAJ`FK_:N[_=0CH
MW1T``%#HZ1T``%G_,/]7,.C,'0``4.C8'0``BSB#Q!B-A2!___]J!E#_=0CH
ML!T``%#HO!T``%G_,/]71(/$$("]('___P`/A;4```"`O2%___]##X6H````
M@+TB?___00^%FP```("](W___T,/A8X```"`O21___](#X6!````@+TE?___
M175XZ%(=``!0Z%X=``!9BSAJ`FK_:L;_=0CH.QT``%#H1QT``%G_,/]7,.@J
M'0``4.@V'0``BSB#Q!B-A2!___]J*5#_=0CH#AT``%#H&AT``%G_,/]71(V%
M('___U-0_S40L$``_W7\:`A#0`#_=?S_UH/$*.DB`0``C84@____4.@V`0``
MZ,X<``!0Z-H<``!968LXC84@?___:`"```!0_W4(Z+`<``!0Z+P<``!9_S#_
M5T2#Q!"%P'XD4(V%('___U"-A2#___]0Z!X!``#HA!P``%#HD!P``(/$$.NS
MZ'0<``!0Z(`<``"+.%G_=0CH8QP``%#H;QP``%G_,/]7$(V%(/___U"-1:Q0
MZ+L3``"-18"#Q!`S_XE%"`^V1#VL4&@`0T``_W4(_]:#10@"@\0,1X/_%'SC
MC46`4X!EJ`!0_S40L$``_W7\:`A#0`#K06B\04``:%Q"0`#H7?7__UE94^CO
M&P``4.@''```BSCHXAL``%#H^AL``/\P_U=H@\0,4/\U$+!``/]U_&CP0D``
M_W7\_]:#Q!C_=?QHL$%``.@6]?___W7\Z/'X__^+1?R#Q`Q?7EO)PXM$)`0S
MR<<``2-%9\=`!(FKS>_'0`C^W+J8QT`,=E0R$,=`$/#ATL.)2!2)2!B)2%S#
M58OL4XM=$%:+=0A7BTX4C039.\%S`_]&&(E&%(O#P>@=`488BT9<A<!T-&I`
M7ROX._M^`HO[BT9<5_]U#(U$!AQ0Z!0<```!?0P!?ER#Q`PKWX-^7$!U2U;H
M2@```%F#^T!\+(O[P>\&B\?WV,'@!@/8:D"-1AS_=0Q0Z-L;``"#10Q`5N@>
M````@\003W7B4XU&'/]U#%#HOAL``(/$#(E>7%]>6UW#58OL@>Q4`0``BT4(
M4U97C5`<C;6L_O__QT4($````(L*@\($B_F+V8'G``#_`,'K$`O[B]F!XP#_
M``#!X1`+V<'O",'C"`O[B3Z#Q@3_30AUS6I`C96T_O__7HM*+#-*&#-*^#,*
M@\($B_D#R<'O'POY3HEZ-'7CBW@$BU`(BW`,BPB+WR/7]],CWHOQ"]J+T<'J
M&\'F!0O6BW`0`_,#UHNUK/[__XV4,IEY@EJ+]\'F'L'O`@OWB_GWUR-X"(EU
M["/QB]H+_HORP>L;P>8%"]Z+M;#^__\#]P/>BW`,C;PSF7F"6HOQB]F)??C!
MYA[!ZP(+\XO:]],C7>R)=?PC\@O>B[6T_O__B5T(B]_!ZQO!YP4+WXM]"`/W
MB_K!YQ[!Z@(#WHMP"`OZBU7XC;0SF7F"6HM=^/?2(U7\(]^)??2+_@O3B][!
M[QO!XP4+^XN=N/[__P/:`_N+5>R-G!>9>8):BWWXB]>)70C!XA[![P(+UXO^
M]]<C??2)5?@CU@OZB]/!ZAO!XP4+TXN=O/[__P/?BWW\`].-E#J9>8):B_[!
MYQ[![@(+_HMU"/?6(W7XB7WP(WT(B]K!XP4+]XOZP>\;"_N+G<#^__\#WHMU
M]`/[C9PWF7F"6HM]"(OWB5W\P>8>P>\""_>+^O?7(WWPB74((_(+_HOSP>X;
MP>,%"_.+G<3^__\#WXM]^`/SC;0^F7F"6HOZP><>P>H""_J+5?SWTB-5"(E]
M["-]_(O>P>,%"]>+_L'O&PO[BYW(_O__`]J+5?`#^XV<%YEY@EJ+??R+UXE=
M^,'B'L'O`@O7B_[WUR-][(E5_"/6"_J+T\'J&\'C!0O3BYW,_O__`]^+?0@#
MTXM=^(V4.IEY@EJ+_L'G'L'N`@O^BW7X]]8C=?PCWXE]](OZ"_.+VL'O&\'C
M!0O[BYW0_O__`]Z+=>P#^XV<-YEY@EJ+??B+]XE=",'F'L'O`@OWB_KWUR-]
M](EU^"/R"_Z+\\'N&\'C!0OSBYW4_O__`]^+??P#\XVT/IEY@EJ+^L'G'L'J
M`@OZBU4(]](C5?B)??`C?0B+WL'C!0O7B_[![QL+^XN=V/[__P/:BU7T`_N-
MG!>9>8):BWT(B]>)7?S!XA[![P(+UXO^]]<C??")50@CU@OZB]/!ZAO!XP4+
MTXN=W/[__P/?BWWX`].-E#J9>8):B_[!YQ[![@(+_HMU_/?6(W4(B7WL(WW\
MB]K!XP4+]XOZP>\;"_N+G>#^__\#WHMU\`/[C9PWF7F"6HM]_(OWB5WXP>8>
MP>\""_>+^O?7(WWLB77\(_(+_HOSP>X;P>,%"_.+G>3^__\#WXM]"`/SBUWX
MC;0^F7F"6HOZP><>P>H""_J+5?CWTB-5_(E]]"/?B_X+TXO>P>\;P>,%"_N+
MG>C^__\#VHM5[`/[C9P7F7F"6HM]^(O7B5T(P>(>P>\""]>+_O?7(WWTB57X
M(]8+^HO3P>H;P>,%"].+G>S^__\#WXM]_`/3C90ZF7F"6HO^P><>P>X""_Z+
M=0CWUB-U^(E]\"-]"(O:P>,%"_>+^L'O&PO[BYWP_O__`]Z+=?0#^XV<-YEY
M@EJ+?0B+]XE=_,'F'L'O`@OWB_KWUR-]\(EU""/R"_Z+\\'N&\'C!0OSBYWT
M_O__`]^+??@#\XVT/IEY@EJ+^L'G'L'J`@OZBU7\]](C50B)?>PC??P+UXO^
MP>\;B][!XP4+^XN=^/[__P/:BU7P`_N-G!>9>8):BWW\B]>)7?C!XA[![P(+
MUXO[P>\;P>,%"_N+7>R)5?PSVHN5_/[__S/>`]>+_@/:BU4(P><>P>X""_Z-
ME!.AZ]ENB7WTB_*+^HN=`/___\'N&\'G!0OWBWWX,WW\`]Z+=>PS??0#^XV<
M-Z'KV6Z+??B+]XE=",'F'L'O`@OWB_O![QO!XP6)=?@+^XN=!/___S/R,W7T
M`]^+??P#\XVT/J'KV6Z+^L'G'L'J`@OZB]:+WHE]\,'J&\'C!0O3BUWX,]^+
MO0C___\S70@#^HM5]`/?C9P3H>O9;HM]"(E=_(O7P>(>P>\""]>+^\'O&\'C
M!0O[BUWPB54(,]J+E0S___\SW@/7B_X#VHM5^,'G'L'N`HV4$Z'KV6X+_HOR
MB]K![AO!XP4+\XM="(E][#/?B[T0____,UW\`_Z+=?`#WXM]_(V<,Z'KV6Z+
M]\'F'L'O`@OWB_N)7?B)=?S![QO!XP4+^XM=[#/>B[44____,]H#]XOZ`]Z+
M=0C!YQ[!Z@(+^HVT,Z'KV6Z)??2+UHO^BYT8____P>H;P><%"]>+??@S??P#
MVHM5[#-]]`/[C9P7H>O9;HM]^(O7B5T(P>(>P>\""]>)5?B+^S/6,U7TP>\;
MP>,%"_N+G1S___\#WXM]_`/3C90ZH>O9;HO^P><>P>X""_Z+\HO:B7WPP>X;
MP>,%"_.+7?@SWXN](/___S-="`/^BW7T`]^+?0B-G#.AZ]ENB_?!YA[![P(+
M]XO[B5W\B74(P>\;P>,%"_N+7?`SWHNU)/___S/:`_<#WHMU^(OZP><>P>H"
MC;0SH>O9;@OZB]:+WL'J&\'C!0O3BUT(B7WL,]^+O2C___\S7?P#^HM5\`/?
MBWW\C9P3H>O9;HO7P>(>P>\""]>+^XE=^(E5_,'O&\'C!0O[BUWL,]J+E2S_
M__\SW@/7B_X#VHM5",'G'L'N`@O^C903H>O9;HE]](ORB_J+G3#____![AO!
MYP4+]XM]^#-]_`/>BW7L,WWT`_N-G#>AZ]ENBWWXB_>)70C!YA[![P(+]XO[
MP>\;P>,%B77X"_N+G33___\S\C-U]`/?BWW\`_.-M#ZAZ]ENB_K!YQ[!Z@(+
M^HO6B]Z)??#!ZAO!XP4+TXM=^#/?B[TX____,UT(`_J+5?0#WXM]"(V<$Z'K
MV6Z+U\'B'L'O`@O7B_N)7?R)50C![QO!XP4+^XM=\#/:BY4\____,]X#UP/:
MBU7XC;P3H>O9;HO6P>(>P>X""]:+]XO?P>X;P>,%"_.+70B)5>PSVHN50/__
M_S-=_`/6BW7\`]J+5?"-G!.AZ]ENB];!XA[![@(+UHOSB5WXB57\P>X;P>,%
M"_.+7>PSVHN51/___S/?`]:+]P/:BU4(P>8>P>\""_>-E!.AZ]ENB77TB_*+
M^HN=2/___\'N&\'G!0OWBWWX,WW\`]Z+=>PS??0#^XVT-Z'KV6Z+??B)=0B+
M]\'F'L'O`@OWB_H+??2+70B)=?@C_HOR(W7TP>,%"_Z+=0C![AL+\XN=3/__
M_P/?BWW\`_.-M#[<O!N/B_K!YQ[!Z@(+^HO7B7WP"U4((U7X(WT(B]X+UXO^
MP>\;P>,%"_N+G5#___\#VHM5]`/[C9P7W+P;CXM]"(O7B5W\P>(>P>\""]>+
M^HE5"`O^(]8C??`+^HO3P>H;P>,%"].+G53___\#WXM]^`/3C90ZW+P;CXO^
MP><>P>X""_Z+VHOWB7WL"W7\(WW\P>,%(W4("_>+^L'O&PO[BYU8____`]Z+
M=?`#^XV<-]R\&X^+??R+]XE=^,'F'L'O`@OWB_Z)=?P+^B/R(WWL"_Z+\\'N
M&\'C!0OSBYU<____`]^+?0@#\XVT/MR\&X^+^L'G'L'J`@OZBU7\B7WTBUW\
M"]<C5?@CWXO^"].+WL'O&\'C!0O[BYU@____`]J+5>P#^XV4%]R\&X^+??B)
M50B+U\'B'L'O`@O7B_X+??2+70B)5?@C^HO6(U7TP>,%"_J+50C!ZAL+TXN=
M9/___P/?BWW\`].-E#K<O!N/B_[!YQ[![@(+_HO:B_>)??`+=0@C?0C!XP4C
M=?@+]XOZP>\;"_N+G6C___\#WHMU]`/[C9PWW+P;CXM]"(OWB5W\P>8>P>\"
M"_>+_HEU"`OZ(_(C??`+_HOSP>X;P>,%"_.+G6S___\#WXM]^`/SC;0^W+P;
MCXOZP><>P>H""_J+WHO7B7WL"U7\(WW\P>,%(U4("]>+_L'O&PO[BYUP____
M`]J+5?`#^XV<%]R\&X^+??R+UXE=^,'B'L'O`@O7B_J)5?P+_B/6(WWL"_J+
MT\'J&\'C!0O3BYUT____`]^+?0@#TXM=_(V4.MR\&X^+_L'G'L'N`@O^BW7\
M"_<CWR-U^(E]](OZ"_.+VL'O&\'C!0O[BYUX____`]Z+=>P#^XVT-]R\&X^+
M??B)=0B+]\'F'L'O`@OWB_H+??2+70B)=?@C_HOR(W7TP>,%"_Z+=0C![AL+
M\XN=?/___P/?`_.+??R-M#[<O!N/B_K!YQ[!Z@(+^HO>B]>)??`+50@C?0C!
MXP4C5?@+UXO^P>\;"_N+78`#VHM5]`/[C9P7W+P;CXM]"(O7B5W\P>(>P>\"
M"]>+^HE5"`O^(]8C??`+^HO3P>H;P>,%"].+780#WXM]^`/3C90ZW+P;CXO^
MP><>P>X""_Z+VHOWB7WL"W7\(WW\P>,%(W4("_>+^L'O&PO[BUV(`]Z+=?`#
M^XV<-]R\&X^+??R+]XE=^,'F'L'O`@OWB_Z)=?P+^B/R(WWL"_Z+\\'N&\'C
M!0OSBUV,`]^+?0@#\XM=_(VT/MR\&X^+^L'G'L'J`@OZBU7\"]<CWR-5^(E]
M](O^"].+WL'O&\'C!0O[BUV0`]J+5>P#^XV4%]R\&X^+??B)50B+U\'B'L'O
M`@O7B_X+??2+70B)5?@C^HO6(U7TP>,%"_J+50C!ZAL+TXM=E`/?BWW\`].-
ME#K<O!N/B_[!YQ[![@(+_HO:B_>)??`+=0@C?0C!XP4C=?@+]XOZP>\;"_N+
M79@#WHMU]`/[C9PWW+P;CXM]"(OWB5W\P>8>P>\""_>+^\'O&\'C!0O[BUWP
M,]Z)=0@SVHMUG`/WB_H#WHMU^,'G'L'J`HVT,];!8LH+^HO6B][!ZAO!XP4+
MTXM="#/?B7WLBWV@,UW\`_J+5?`#WXM]_(V<$];!8LJ+U\'B'L'O`@O7B_N)
M7?B)5?S![QO!XP4+^XM=[#/:BU6D,]X#UXO^`]J+50C!YQ[![@(+_HV4$];!
M8LJ)??2+\HOZBUVHP>X;P><%"_>+??@S??P#WHMU[#-]]`/[C9PWUL%BRHM]
M^(OWB5T(P>8>P>\""_>+^\'O&\'C!8EU^`O[BUVL,_(S=?0#WXM]_`/SC;0^
MUL%BRHOZP><>P>H""_J+UHO>B7WPP>H;P>,%"].+7?@SWXM]L#-="`/ZBU7T
M`]^+?0B-G!/6P6+*B]?!XA[![P(+UXO[B5W\B54(P>\;P>,%"_N+7?`SVHM5
MM#/>`]<#VHM5^(O^P><>P>X"C903UL%BR@O^B_*+VL'N&\'C!0OSBUT(B7WL
M,]^+?;@S7?P#_HMU\`/?BWW\C9PSUL%BRHOWP>8>P>\""_>+^XE=^(EU_,'O
M&\'C!0O[BUWL,]Z+=;PSV@/WB_H#WHMU",'G'L'J`@OZC;0SUL%BRHE]](O6
MB_[!ZAO!YP4+UXM]^(M=P#-]_`/:BU7L,WWT`_N-G!?6P6+*BWWXB]>)70C!
MXA[![P(+UXO[P>\;P>,%B57X"_N+7<0SUC-5]`/?BWW\`].-E#K6P6+*B_[!
MYQ[![@(+_HORB]J)??#![AO!XP4+\XM=^#/?BWW(,UT(`_Z+=?0#WXM]"(V<
M,];!8LJ+]\'F'L'O`@OWB_N)7?R)=0C![QO!XP4+^XM=\#/>BW7,,]H#]P/>
MBW7XB_K!YQ[!Z@*-M#/6P6+*"_J+UHO>P>H;P>,%"].+70B)?>PSWXM]T#-=
M_`/ZBU7P`]^-G!/6P6+*BWW\B5WXB]?!XA[![P(+UXO[P>\;P>,%"_N+7>R)
M5?PSVHM5U#/>`]>+_@/:BU4(P><>P>X""_Z-E!/6P6+*B7WTB_*+^HM=V,'N
M&\'G!0OWBWWX,WW\`]Z+=>PS??0#^XV<-];!8LJ+??B+]XE=",'F'L'O`@OW
MB_O![QO!XP6)=?@+^XM=W#/R,W7T`]^+??P#\XVT/M;!8LJ+^L'G'L'J`@OZ
MB]:+WHE]\,'J&\'C!0O3BUWX,]^+?>`S70@#^HM5]`/?BWT(C9P3UL%BRHO7
MP>(>P>\""]>)7?R)50B+^\'O&\'C!0O[BUWP,]J+5>0SW@/7`]J+5?B+_L'G
M'L'N`HV4$];!8LJ+70@+_HORB57T,]_![AO!X@4+\HM5_#/:`\X#V8M-\`-=
MZ(MU](V,"];!8LJ)"(M(!`/.B4@$B\K!X1[!Z@(+RHM5"`-("(E("(M(#`//
M7XE(#(M($`/*7HE($%O)PU6+[%-6BW4,BT88BUX4B44,B\/!Z`.#X#_&1#`<
M@$"#^#A^*FI`62O(C40P'%%J`%#H3`D``%;HC>W__VHXC48<:@!0Z#D)``"#
MQ!SK%6HX62O(C40P'%%J`%#H(@D``(/$#(M%#%:+R(A&5\'I&(A.5(O(P>D0
MB$Y5B\B+P_]U",'H&(A&6(O#P>@0B$99B\/!Z0C!Z`B(3E:(1EJ(7EOH!@``
M`%E97EM=PU:+="0,5N@3[?__BT0D#%F+#L'I&(@(BP[!Z1"(2`&+#L'I"(A(
M`HH.B$@#BU8$C4X$P>H8B%`$BQ'!ZA"(4`6+$<'J"(A0!HH)B$@'BU8(C4X(
MP>H8B%`(BQ'!ZA"(4`F+$<'J"(A0"HH)B$@+BU8,C4X,P>H8B%`,BQ'!ZA"(
M4`V+$<'J"(A0#HH)B$@/BU80C4X07L'J&(A0$(L1P>H0B%`1BQ'!Z@B(4!**
M"8A($\.!["0!``!3BYPD+`$``%97A=L/A#$"``!3Z,<'``"%P%D/A"("``!3
MZ+@'``"+\('&`@$``.CU!@``4.@'!P``BSA965;HY08``%#H]P8``%G_,/\7
MBSV40$``B_!3:(!#0`!6_]>-1"0L4%;_%4A`0`"#Q!R#^/^)1"04#X3'`0``
M58LMA$!``(U$)#!H4$%``%#_U5F%P%F-1"0P4'4.4VAX0T``5O_7@\00ZPMH
M=$-``%;_UX/$#+MP0T``4U;_U8OX687_670>4U?H#@<``%F%P%ET+&AL0T``
M5^C]!@``687`670;]D0D'!!T7(.\)#P!````=%)J`5;H__[__UE9C40D'%#_
M="0<_Q5,0$``687`60^%$P$``(U$)#!H4$%``%#_U5F%P%F-1"0P4'5;_[0D
M/`$``&AX0T``5O\5E$!``(/$$.M2C40D,%#_%1!`0`"#9"00`(L]4$!``(E$
M)!16_]>%P%ETEHM$)!#_1"00@_@*?8F#?"04`'0*_W0D%/\5#$!``%;KV&AT
M0T``5O\5E$!``(/$#%-6_]6+^%F%_UET)E-7Z"\&``!9A<!9#X1)____:&Q#
M0`!7Z!H&``!9A<!9#X0T____]D0D'!!T#H.\)#P!````#X45____C40D,%#_
M%1!`0`"#9"00`(L]4$!``(E$)!16_]>%P%D/A/G^__^+1"00_T0D$(/X"@^-
MZ/[__X-\)!0`=`K_="04_Q4,0$``5NO0_W0D&/\55$!``/^T)#P!``#_%:!`
M0`!965U?7EN!Q"0!``##4U:+="0,5U;H_M___XOX5^C,W___68O86>C4X?__
MA<!T-(7V=#!6Z&8%``"%P%ET)6@D0T``4_\5A$!``%D[PUEU$VH!5NAB_?__
M:@!7Z%K]__^#Q!!?7EO#48-D)```4U97Z'0$``!0Z,@$``!J`5N(&,<$)'1"
M0`#H-=W__X7`670+@#@Q=0:`>`$`=`7H_=___VH*4VCL0T``Z#L$``!0Z(D$
M``"#Q!"%P`^$H@```(L`.1T\M$``58OSBT`@BW@0?F.]```$`(U&_VH`4%?H
M!@0``%#H3@0``(/$$(7`=$6+`(M(""/-.\UU!HL`BP#K$VH":@!0Z-X#``!0
MZ"`$``"#Q!!0H4"T0`#_-+#H=P0``%F%P%EU#?]$)!!&.S4\M$``?**A/+1`
M`%V-2/\Y3"0,=1T[PXOS?A=7Z)D#``!0Z-4#``!&63LU/+1``%E\Z6H$4VCH
M0T``Z'L#``!0Z,D#``"+\(/$$(7V=#6+!FC<0T``BT`@_S#H6P,``%#HD0,`
M`(L&@\0,BT`@BP#V0`E`=`Y0Z#\#``!0Z&\#``!966H$4VC80T``Z"H#``!0
MZ'@#``"+\(/$$(7V=')HH$%``.CIV___A<!9=`-0ZTOH2N#__XOXA?]T.8L&
M5XM`(/\PZ/$"``!0Z"<#``#HY@(``%#H^`(``(LP@\005^C5`@``4.CG`@``
M6?\P_U8(65GK'*%`M$``_S"+!HM`(/\PZ+("``!0Z.@"``"#Q`SHI`(``%#H
M^`(``(`@`.B6`@``4.C``@``@R``:+!!0`#H6]O__X/$#*,XL$``A<!U$?\U
M0+1``.C"X/__6:,XL$``Z&$"``!0Z(4"``"+,,<$).T!``#_-3BP0`#H1P(`
M`%#H:P(``%G_,/\6@\0,A<!?7EMT)8/X$70@@_C_=!M0H4"T0`#_-3BP0`#_
M,&B(0T``Z#0"``"#Q!!9PU6+[%%15HU%#%=0C44(4/\5K$!``#/_5^B$`@``
M@\0,@#@`=4OH<0(``#O'HS2P0`!U(^C3`0``4.CK`0``BS!9:@'HPP$``%#H
MVP$``%G_,/]6"%E9_S4TL$``Z#0"``#HI0$``%#H(P(``%F).%GHE@$``%#H
M#@(``(`(`NB(`0``4.@``@``@`@!BT4(@\`%B7W\B47X6=]M^%G<'1!$0`#?
MX)YV"VC\0T``Z'T!``!9BT4(C02%%````%#HP`$``%FC0+1``(M-#&H!BPF)
M"*%`M$``QT`$^$-``*%`M$``QT`(,$1``*%`M$``QP4\M$```P```,=`#/1#
M0`#_!3RT0`!8.44(?AZ+#3RT0`"+50R+-4"T0``#R(L4@D")5([\.T4(?.*A
M/+1``(M-"`/!BPU`M$``5XE\@?RA/+1``(M-"/\U0+1``(U$"/]0:.8X0`#_
M-32P0`#H&P$``(OP@\04._=U#O\U-+!``.@!`0``68OP_S4TL$``Z.T```#'
M!"1H0D``Z%/9__^%P%EU)*$XL$``.\=U%&BP04``Z#O9__\[QUFC.+!``'0'
M4.AW^___6?\U-+!``.BG````6?\5V$!``(O&7U[)P^@U````4.@/U___6;BH
M0D``:@!04&B>-$``:!A$0`#H%@```%#HK````(/$&,/_)2!!0`#_)1Q!0`#_
M)1A!0`#_)11!0`#_)1!!0`#_)0Q!0`#_)0A!0`#_)01!0`#_)0!!0`#_)?Q`
M0`#_)?A`0`#_)?1`0`#_)?!`0`#_)>Q`0`#_)>A`0`#_)>1`0`#_)>!`0`#_
M)=Q`0`#_)=1`0`#_)=!`0`#_)<Q`0`#_)<A`0`#_)<1`0`#_)<!`0`#_);Q`
M0`#_);A`0`#_);1`0`#_);!`0`#_):A`0`#,S,S,S,S,S,S,S,S,S/\ED$!`
M`/\EB$!``,S,S,Q1/0`0``"-3"0(<A2!Z0`0```M`!```(4!/0`0``!S["O(
MB\2%`8OABPB+0`10P\S_)6!`0`#_)5Q`0`#,S,S,58OL:O]HR)]``&A0.T``
M9*$`````4&2))0````"#["!35E>)9>B#9?P`:@'_%5A`0`!9@PU8M$``_X,-
M7+1``/__%1A`0`"+#52T0`")"/\5'$!``(L-4+1``(D(H2!`0`"+`*-@M$``
MZ,````"#/3"P0```=0QH9A9``/\5)$!``%GHE````&@,L$``:`BP0`#H?P``
M`*%,M$``B478C4784/\U2+1``(U%X%"-1=10C47D4/\5+$!``&@$L$``:`"P
M0`#H3````/\5,$!``(M-X(D(_W7@_W74_W7DZ!+\__^#Q#")1=Q0_Q4T0$``
MBT7LBPB+"8E-T%!1Z`\```!96<.+9>C_==#_%3Q`0`#_)3A`0`#_)2A`0`!H
M```#`&@```$`Z`L```!96</#S/\EF$!``/\EG$!`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````.2C````````GJ,``+2C``#"HP```````(*E``!RI0``8J4``$ZE``!"
MI0``,J4``"*E```:I0``#*4```2E``#LI```XJ0``-2D``#(I```OJ0``+"D
M``"0I0``G*0``)*D``""I```=J0``&RD``!BI```6*0``$ZD``!$I```-*0`
M`"JD```@I```%J0```RD```"I```HJ4``+:E``"FI````````'ZC``!LHP``
M5J,``$BC```VHP``%J,``/ZB``#HH@``VJ(``,ZB``"^H@``LJ(``*"B``",
MH@``>J(``&JB``!6H@``1J(``#:B```HH@``%*(```2B``#LH0``VJ$``,JA
M``"ZH0``IJ$``)2A``"`H0``<J$``&"A````````````````````````+C`K
M2``````"````0```````````X```.P```%P```!7:6XS,D-/4D4Z.F)O;W1S
M=')A<`````!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`<&5R;'AS:2YC
M````)7,E<R5S```N````4$%27U!23T=.04U%`````%!!4E]414U0`````#$`
M``!005)?0TQ%04X]``!#3$5!3@```%!!4E]'3$]"04Q?0TQ%04X`````4$%2
M7T=,3T)!3%]414U0`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$U01$E2````
M4$%27T=,3T)!3%]$14)51P````!005)?05)'5E\P``!005)?05)'0P````!0
M05)?0T%#2$4```!005)?1$5"54<```!005)?0TQ%04X```!005)?4U!!5TY%
M1`!005)?24Y)5$E!3$E:140`7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@
M("`@("```````````$193$1?3$E"4D%265]0051(````4$%42`````!,24)2
M05)97U!!5$@`````3$E"4$%42`!,1%],24)205)97U!!5$@`)7,E<W1E;7`M
M)74E<P```"4P,G@`````)7,E<V-A8VAE+25S)7,``"5S)7,E<R5S`````'!A
M<BT`````4UE35$5-``!54T523D%-10````!54T52`````%1-4`!414U0````
M`%1%35!$25(`5$U01$E2``!#.EQ414U0`%PN+@!<+@``)7,``"5S7"5S````
M)7-<*BXJ```E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@```#``
M``!P97)L+F5X90`````8````05)'5@`````M+0``+64``'!A;FEC.B!M96UO
M<GD@=W)A<`````"`____ST%);G1E<FYA;',Z.E!!4CHZ0D]/5``````C(2]U
M<W(O8FEN+W!E<FP*"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE
M('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@
M;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*
M(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34Y"@IM>2`H)'!A<E]T96UP+"`D<')O
M9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@
M;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`["B`@
M("!R;61I<B`D=&]P9&ER.PH*("`@(&EF("@M9"`D<&%R7W1E;7`I('L*("`@
M("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H
M87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S
M:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA
M="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@
M("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@
M:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*"B`@("`@("`@;7D@)'1M<"`](&YE
M=R!&:6QE.CI496UP*`H@("`@("`@("`@("!414U03$%412`]/B`G=&UP6%A8
M6%@G+`H@("`@("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@
M("`@("`@("`@(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@("`@(",@
M0F5C875S92!T:&4@<&%R7W1E;7`@9&ER96-T;W)Y(&ES(&=O:6YG('1O(&)E
M(&1E;&5T960@:6X@80H@("`@("`@(",@8F%C:V=R;W5N9"!P<F]C97-S+"!T
M:&4@<&%R96YT('!R;V-E<W,@:60@;6%Y(&)E(')E=7-E9"!B969O<F4@=&AE
M"B`@("`@("`@(R!B86-K9W)O=6YD('!R;V-E<W,@8V]M<&QE=&5S+B`@5&\@
M96YS=7)E('1H870@=&AE('1E;7!O<F%R>0H@("`@("`@(",@9&ER96-T;W)Y
M(&1O97,@;F]T(&=E="!R975S960@=VAI;&4@:70@:7,@8F5I;F<@9&5L971E
M9"P@=')Y('1O"B`@("`@("`@(R!R96YA;64@:70@=&\@82!N86UE('1H870@
M:7,@<F5L871E9"!T;R!T:&4@=&5M<&]R87)Y('-C<FEP="!F:6QE+@H*(R!&
M25A-13H@5&AI<R!B<F5A:W,@=&AR96%D960@87!P;&EC871I;VYS+B!!(&9I
M>"!I<R!I;B!T:&4@=V]R:W,L(&)U="!M87D*(R`@("`@("`@<W1I;&P@=&%K
M92!A('=H:6QE+B!4:&4@9FEX('=O=6QD(&)E('1O(&UA:V4@<W5R92!T:&%T
M('1H:7,@:7,@;VYL>0HC("`@("`@("!R=6X@:6X@=&AE($Q!4U0@4D5-04E.
M24Y'('1H<F5A9"X*("`@("`@("`*(R`@("`@("`@;7D@)'1M<&YA;64@/2`H
M1FEL93HZ4W!E8RT^<W!L:71P871H*"1T;7`M/F9I;&5N86UE*2E;,ET[(",@
M9FEL96YA;64*(R`@("`@("`@)'1M<&YA;64@/7X@<R]<+EM>+ETJ)"\N9&ER
M+SL*(R`@("`@("`@;7D@)&YE=T1I<B`]($9I;&4Z.E-P96,M/F-A='!A=&@H
M"B,@("`@("`@("`@("`H1FEL93HZ4W!E8RT^<W!L:71P871H*"1P87)?=&5M
M<"DI6S`N+C%=+"`D=&UP;F%M92D["B,@("`@("`@(&EF("AR96YA;64@)'!A
M<E]T96UP+"`D;F5W1&ER*2!["B,@("`@("`@("`@("!O=71S*")296YA;65D
M("1P87)?=&5M<"!T;R`D;F5W1&ER(BD["B,@("`@("`@("`@("`D<&%R7W1E
M;7`@/2`D;F5W1&ER.PHC("`@("`@("!]"@H@("`@("`@(&EF("@D7D\@/7X@
M;2]W:6XS,B]I*2!["B`@("`@("`@("`@('!R:6YT("1T;7`@(@HZ;&]O<`IR
M;61I<B`O<2`O<R!<(B1P87)?=&5M<%PB"FEF(&5X:7-T(%PB)'!A<E]T96UP
M7"(@9V]T;R!L;V]P"G)M9&ER(%PB)'1O<&1I<EPB"G)M(%PB(B`N("1T;7`M
M/F9I;&5N86UE("X@(EPB"B(["B`@("`@("`@("`@(&-L;W-E("1T;7`["B`@
M("`@("`@("`@(&UY("1P<F]C.PH@("`@("`@("`@("!7:6XS,CHZ4')O8V5S
M<SHZ0W)E871E*`H@("`@("`@("`@("`@("`@)'!R;V,L("1%3E9[0T]-4U!%
M0WTL"B`@("`@("`@("`@("`@("`B)$5.5GM#3TU34$5#?2`O8R!<(B(@+B`D
M=&UP+3YF:6QE;F%M92`N(")<(B`^;G5L(#(^;G5L("(L"B`@("`@("`@("`@
M("`@("`Q+"!.3U)-04Q?4%))3U))5%E?0TQ!4U,L("(N(@H@("`@("`@("`@
M("`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!R:6YT("1T;7`@
M(B,A+V)I;B]S:`IW:&EL92!;("UD("<D<&%R7W1E;7`G(%T[(&1O"B`@(')M
M("UR9B`G)'!A<E]T96UP)PID;VYE"G)M9&ER("<D=&]P9&ER)PIR;2`G(B`N
M("1T;7`M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@,#<P
M,"PD=&UP+3YF:6QE;F%M93L*("`@("`@("`@("`@;7D@)&-M9"`]("1T;7`M
M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@("`@
M(&-L;W-E("1T;7`["B`@("`@("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@
M("!]"B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`I*3L*("`@('T*?2!]"@I"14=)3B!["B`@
M("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*
M:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=6
M7S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@
M*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?
M05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@
M("`@9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*
M;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M
M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@
M("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA
M;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI
M;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T
M87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?
M7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R
M="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O
M9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F
M.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@[
M"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S
M965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S
M965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D
M(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O
M(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H
M)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@
M("`@("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5
M;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&
M2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT
M("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H
M)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@
M("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H
M)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@
M("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@
M,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65]
M(#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL
M;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-
M4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP
M9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]4
M14U0?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG
M+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O
M=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@
M(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D
M4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@
M("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^
M("1C<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@
M("`@("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L
M(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*
M("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E
M='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@
M)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@
M9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H
M("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@
M=6YL97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@("`@)&ME>2`]
M("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@
M?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E
M<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@
M("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$[
M"B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@
M)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P
M+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@
M("`@96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M
M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I
M9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@
M("`@("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@
M("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@
M("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D9F@[
M"B`@("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D
M.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@
M(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET
M:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!8
M4TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@
M0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@
M(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L
M970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@
M("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@
M9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES
M("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W
M9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@
M("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)3
M1%!!3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T
M:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M
M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E("1F
M:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI
M>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S
M<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[
M>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'
M?3L*"B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X
M96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O
M7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN
M<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E
M<FEF>5]P87(*("`@("D["@H@("`@;7D@0&%D9%]T;U]I;F,["B`@("!W:&EL
M92`H0$%21U8I('L*("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q
M<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("!I9B`H)#$@97$@)TDG
M*2!["B`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@
M('T*("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@(&5V
M86P@(G5S92`D,B(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G
M02<I('L*("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@
M("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@
M("1O=70@/2`D,CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=B
M)RD@>PH@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@("1B=6YD
M;&4@/2`G86QL)SL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=Q
M)RD@>PH@("`@("`@("`@("`D<75I970@/2`Q.PH@("`@("`@('T*("`@("`@
M("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@(&]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@
M("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("!]"@H@("`@("`@('-H
M:69T*$!!4D=6*3L*"B`@("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C;61[
M)#%]*2!["B`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@
M("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("!R97%U:7)E(%!!
M4CHZ1&ES=#L*("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U
M;FQE<W,@0$%21U8["B`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@(&5X:70["B`@("`@("`@?0H@
M("`@?0H*("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*"B,@6%A8
M("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T
M(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@
M("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@
M;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H*("`@(&UY("1P87(@
M/2!S:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE
M9"`D<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D
M:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H
M)&9H*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@
M("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R
M<F]R.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,[
M"B`@("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@
M("`D;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@
M("`@?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*
M("`@(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@
M("`@("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B([
M"B`@("`@("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N
M;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*
M("`@('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&
M:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A
M.PH@("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?
M<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P
M.PH@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.
M5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI
M+RD@>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@
M("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO
M861E<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y
M<R`E96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X
M=#L*("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=
M+SL*("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y
M*2`N(")?7R(["B`@("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI
M("X@(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U[
M"B`@("`@("`@("`@("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D
M,2D@+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F
M:"T^<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*
M"B`@("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N
M9&QE*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN
M8R@I.PH@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`
M:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T
M:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*
M("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET
M92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@:68@
M*"1#;VYF:6=[7V1E;&EM?2!E<2`G7%PG*2![('-[7%Q]>R]]9R!F;W(@0&EN
M8R!]"@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N
M9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD
M7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N
M.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@
M("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@
M/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@
M("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<
M421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@
M("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@
M("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N
M>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T
M<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@
M("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D
M8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@
M("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&
M24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B
M.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@
M("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@
M1DE,13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@
M("`@("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH
M/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@(R!$;R!N;W0@;&5T
M(%A33&]A9&5R('!I8VL@=7`@875T;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@
M("`@("`@("`@("`@("1C;VYT96YT(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S
M<R`K+BHO9V]T;R!R971R>3LO"B`@("`@("`@("`@("`@("`@("`@:68@;&,H
M)&YA;64I(&5Q(&QC*")84TQO861E<BYP;2(I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@
M("`@("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX
M+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D
M;F%M90H@("`@("`@("`@("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M
M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*
M("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S
M('M[>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP
M.PH*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T
M,#L*("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1O=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@
M("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA
M<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@
M("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G
M-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@
M('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P
M96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@
M("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M
M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@
M("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO
M861E<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F
M:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@
M("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2
M(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A
M9"!T:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@
M>WM["B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@
M<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ
M6FEP.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@
M("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z
M.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@
M(&]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI
M.PH*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB97)?
M;F%M92`]("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@
M("`@("`@("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N
M9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@("A;
M7B]=*RD*("`@("`@("`@("`@("`@("0*("`@("`@("`@("`@?7@["B`@("`@
M("`@("`@(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PH@("`@("`@("`@("!I9B`H+68@)&1E<W1?
M;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@
M>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N
M86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@("`@
M("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O
M(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A
M9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;
M('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=
M(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U
M8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@
M"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M
M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?
M(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R
M97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R
M97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U
M:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z
M.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U
M:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@
M1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I
M<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@
M24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E
M($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@
M("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E
M<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R
M97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,CHZ4')O
M8V5S<R!].PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@
M("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*?0H*
M(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R
M+VUK=&UP9&ER+F,*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@:68@*"1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@
M("`@("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@
M("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@
M<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@
M("`@("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N
M97AT('5N;&5S<R`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PH@
M("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@("`@
M("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A;"![
M*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*("`@
M("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@("`@
M("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@
M("!]"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@("`@
M("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@96QS
M92!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\
M("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@("`@("1U
M<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B
M)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M)'5S97)N86UE(CL*("`@("`@("!M
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%27T-,
M14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*
M("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["B`@
M("`@("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y<W)E
M860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E<2`B
M7#!#04-(12(I('L*("`@("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L(#([
M"B`@("`@("`@("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@("`@
M("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@("`D
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@
M("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S
M=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@
M("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@("`@(R!7
M;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS
M.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$
M:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@("!I
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D
M<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*("`@
M("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK9&ER
M("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@)'!A
M<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H)&5X
M="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@("`@
M)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@
M+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M
M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L("1F
M:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E;B`D
M9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H
M*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D["GT*"G-U8B!?<V5T7W!R
M;V=N86UE('L*("`@(&EF("@D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@
M/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D
M14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]4
M14U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O
M9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q
M*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@
M(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@
M("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@("`@("`@:68@*"US
M("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<
M421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@
M;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.
M5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@
M("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B
M(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[
M4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C
M:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)D-W
M9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@("`@("`@("`@(#H@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E
M;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]
M"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%3E9[4$%27TE.251)
M04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N.PH@("`@?2!E;'-E
M('L*("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PH@("`@?0H*
M("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!0
M4D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@(&1E;&5T92`D14Y6
M>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!435!$25(@5$5-4"!#
M3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I9B`H)$5.5GM005)?
M5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PH@("`@
M?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@
M>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K
M(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@
M)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*("`@('T*?0H*
M<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G
M9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@
M96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI
M=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H($!)3D,L(&=R
M97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@
M("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB
M97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*("`@("D[
M"GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN('!A
M8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E
M<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2
M+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P
M96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D
M:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA;64["@ID;R`D<')O
M9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?7T524D]2(#T@)$`@
M:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%
M4E)/4CL*"C$["@HC;&EN92`Q,#(Q"@I?7T5.1%]?"@!P87(N<&P```````#_
M____$#M``"0[0`#@H`````````````"2HP``J$```$"@`````````````-:C
M```(0```.*``````````````]*,```!```!0H`````````````#XI```&$``
M````````````````````````````Y*,```````">HP``M*,``,*C````````
M@J4``'*E``!BI0``3J4``$*E```RI0``(J4``!JE```,I0``!*4``.RD``#B
MI```U*0``,BD``"^I```L*0``)"E``"<I```DJ0``(*D``!VI```;*0``&*D
M``!8I```3J0``$2D```TI```*J0``""D```6I```#*0```*D``"BI0``MJ4`
M`*:D````````?J,``&RC``!6HP``2*,``#:C```6HP``_J(``.BB``#:H@``
MSJ(``+ZB``"RH@``H*(``(RB``!ZH@``:J(``%:B``!&H@``-J(``"BB```4
MH@``!*(``.RA``#:H0``RJ$``+JA``"FH0``E*$``("A``!RH0``8*$`````
M```=!6)O;W1?5VEN,S)#3U)%``#A`U!E<FQ?;F5W6%,````#4&5R;%]G971?
M8V]N=&5X=```'`5B;V]T7T1Y;F%,;V%D97(`9P)097)L7U1S=&%T8G5F7W!T
M<@"W`%!E<FQ?24Q)3U]P='(`N@!097)L7TE-96U?<'1R`+X`4&5R;%])4')O
M8U]P='(``,8"4&5R;%]C<F]A:U]N;V-O;G1E>'0``+4`4&5R;%])1&ER7W!T
M<@#6`%!E<FQ?26-O;7!C=E]P='(``)0#4&5R;%]M9U]S970`N01097)L7W-V
M7W-E='!V`(("4&5R;%]A=E]S:&EF=`!J!%!E<FQ?<W9?,G!V7V9L86=S`'L"
M4&5R;%]A=E]F971C:``B`U!E<FQ?9W9?9F5T8VAP=@!K`E!E<FQ?5'1A:6YT
M961?<'1R`!D%4&5R;%]W:6XS,E]T97)M`"<%<&5R;%]F<F5E`"8%<&5R;%]D
M97-T<G5C=``J!7!E<FQ?<G5N```I!7!E<FQ?<&%R<V4``!\$4&5R;%]S869E
M<WES;6%L;&]C``#W`%!E<FQ?265X:71?9FQA9W-?<'1R``!B`5!E<FQ?27!E
M<FQ?9&5S=')U8W1?;&5V96Q?<'1R`"4%<&5R;%]C;VYS=')U8W0``!\%<&5R
M;%]A;&QO8P``F`!097)L7T=D;U]U;F1U;7!?<'1R`!@%4&5R;%]W:6XS,E]I
M;FET`.(#4&5R;%]N97=84U]F;&%G<P``<&5R;#4X+F1L;```=0%'971-;V1U
M;&5&:6QE3F%M94$``.\`1G)E94QI8G)A<GD`=P%'971-;V1U;&5(86YD;&5!
M``!+15).14PS,BYD;&P``",!1V5T57-E<DYA;65!``!!1%9!4$DS,BYD;&P`
M`+("<W!R:6YT9@"X`G-T<F-M<```QP)S=')T;VL``+X"<W1R;&5N``#%`G-T
M<G-T<@``;0!?7W!?7V5N=FER;VX``)@";65M;6]V90#!`G-T<FYC<'D`P`)S
M=')N8VUP`((!7VUK9&ER``".`5]P8W1Y<&4`%0%?:7-C='EP90``80!?7VUB
M7V-U<E]M87@``)<";65M8W!Y``"9`FUE;7-E=```F0%?<FUD:7(``-\`7V9I
M;F1C;&]S90``W0%?=6YL:6YK`.(`7V9I;F1N97AT`.``7V9I;F1F:7)S=```
MOP%?<W1R9'5P`,4!7W-T<FYI8VUP`$U35D-25"YD;&P``-,`7V5X:70`2`!?
M6&-P=$9I;'1E<@!)`F5X:70``&0`7U]P7U]?:6YI=&5N=@!8`%]?9V5T;6%I
M;F%R9W,`#P%?:6YI='1E<FT`@P!?7W-E='5S97)M871H97)R``"=`%]A9&IU
M<W1?9F1I=@``:@!?7W!?7V-O;6UO9&4``&\`7U]P7U]F;6]D90``@0!?7W-E
M=%]A<'!?='EP90``R@!?97AC97!T7VAA;F1L97(S``"W`%]C;VYT<F]L9G``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````4$%``$Q!0`#_____O)]``(M;
M```````````````````!````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````#``,````H``"`#@```$@``(`0
M````8```@````````````````````@`!````>```@`(```"0``"`````````
M```````````!`&4```"H``"````````````````````!``$```#```"`````
M```````````````!``````#8```````````````````````!``````#H````
M```````````````````!``````#X```````````````````````!```````(
M`0``F,,``&@%``````````````#)``"H"`````````````"HT0``(@``````
M````````(,$``'0"````````````````````````=`(T````5@!3`%\`5@!%
M`%(`4P!)`$\`3@!?`$D`3@!&`$\``````+T$[_X```$`````````````````
M`````#\````!````!``$``$```````````````````#4`0```0!3`'0`<@!I
M`&X`9P!&`&D`;`!E`$D`;@!F`&\```"P`0```0`P`#0`,``P`#``-`!B`#``
M```8`````0!#`&\`;0!M`&4`;@!T`',````@`````0!#`&\`;0!P`&$`;@!Y
M`$X`80!M`&4``````"@````!`$8`:0!L`&4`1`!E`',`8P!R`&D`<`!T`&D`
M;P!N```````@`````0!&`&D`;`!E`%8`90!R`',`:0!O`&X``````"`````!
M`$D`;@!T`&4`<@!N`&$`;`!.`&$`;0!E````)`````$`3`!E`&<`80!L`$,`
M;P!P`'D`<@!I`&<`:`!T````*`````$`3`!E`&<`80!L`%0`<@!A`&0`90!M
M`&$`<@!K`',``````"@````!`$\`<@!I`&<`:0!N`&$`;`!&`&D`;`!E`&X`
M80!M`&4````@`````0!0`'(`:0!V`&$`=`!E`$(`=0!I`&P`9````"`````!
M`%``<@!O`&0`=0!C`'0`3@!A`&T`90``````)`````$`4`!R`&\`9`!U`&,`
M=`!6`&4`<@!S`&D`;P!N````(`````$`4P!P`&4`8P!I`&$`;`!"`'4`:0!L
M`&0```!$`````0!6`&$`<@!&`&D`;`!E`$D`;@!F`&\``````"0`!````%0`
M<@!A`&X`<P!L`&$`=`!I`&\`;@````````2P!``````H````$````"`````!
M``@````````!```````````````!`````0``!@8&``0$!``"`@(``````$)"
M0@"=G9T`;FYN`(&!@0"QL;$`____`'-S<P"?GY\`6%A8`+*RL@#]_?T`:VMK
M`/S\_`#7U]<`%A86`-K:V@"6EI8`CHZ.`$9&1@#+R\L`"PL+`*"@H`#^_OX`
MR<G)`,'!P0`#`P,`$1$1`).3DP"SL[,`[N[N`/3T]`#CX^,`Y>7E`**BH@"Z
MNKH`KZ^O``<'!P!Q<7$`M;6U`/7U]0")B8D`BHJ*`#0T-`#HZ.@`-34U`%I:
M6@"WM[<`V-C8`-#0T``='1T`#`P,`(^/CP"^OKX`;6UM``D)"0";FYL`+R\O
M`,W-S0#9V=D`&1D9`$U-30!$1$0`4%!0`#P\/`!D9&0`PL+"`#(R,@`("`@`
M#0T-``\/#P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````%!04%!04%!04%!04%!00$!`35`(P5!,4-!041%
M+@$!`0$!`0$%`3P7%P$!$P$!`0$!`0$!%0$!)A4!`0\!`0$!`0$!`1,!$0$%
M-0$F`0$!`0$!`0$B$A`Q#P4!(`$!`0$!`0$!$`H@(A45+B$N`0$!`0$?("$0
M(A`C(R4F)P$!`0$E$!`0$!`0$!`0%T4!`0%!$!`0$!`0$!`0$!`7`0$!#Q`0
M%1`0$!`0$!`0`0$!`1(0$!,?$!`0$!`0!P$!`0$@$!`0`0\0$!`0$0$!`0$!
M!R`0"@$!!1`0$#$!`0$!`0$!`0$!`0%!!0\!`0$!`0$!`0$!`0$!`0$!`0$!
M`0&``0``P`$``.`#``#P`P``\`,``/`#``#@`P``P`$``(`!``"``0``@`,`
M`(`#````!P````<``(X/``#_'P``*````"````!``````0`(````````!```
M`````````````0````$````````!`0$``@("``,#`P`$!`0`!04%``8&!@`'
M!P<`"`@(``D)"0`*"@H`"PL+``P,#``-#0T`#@X.``\/#P`0$!``$1$1`!(2
M$@`3$Q,`%!04`!45%0`6%A8`%Q<7`!@8&``9&1D`&AH:`!L;&P`<'!P`'1T=
M`!X>'@`?'Q\`("`@`"$A(0`B(B(`(R,C`"0D)``E)24`)B8F`"<G)P`H*"@`
M*2DI`"HJ*@`K*RL`+"PL`"TM+0`N+BX`+R\O`#`P,``Q,3$`,C(R`#,S,P`T
M-#0`-34U`#8V-@`W-S<`.#@X`#DY.0`Z.CH`.SL[`#P\/``]/3T`/CX^`#\_
M/P!`0$``04%!`$)"0@!#0T,`1$1$`$5%10!&1D8`1T='`$A(2`!)24D`2DI*
M`$M+2P!,3$P`34U-`$Y.3@!/3T\`4%!0`%%140!24E(`4U-3`%145`!5554`
M5E96`%=75P!86%@`65E9`%I:6@!;6UL`7%Q<`%U=70!>7EX`7U]?`&!@8`!A
M86$`8F)B`&-C8P!D9&0`965E`&9F9@!G9V<`:&AH`&EI:0!J:FH`:VMK`&QL
M;`!M;6T`;FYN`&]O;P!P<'``<7%Q`')R<@!S<W,`='1T`'5U=0!V=G8`=W=W
M`'AX>`!Y>7D`>GIZ`'M[>P!\?'P`?7U]`'Y^?@!_?W\`@("``(&!@0""@H(`
M@X.#`(2$A`"%A84`AH:&`(>'AP"(B(@`B8F)`(J*B@"+BXL`C(R,`(V-C0".
MCHX`CX^/`)"0D`"1D9$`DI*2`).3DP"4E)0`E965`):6E@"7EY<`F)B8`)F9
MF0":FIH`FYN;`)R<G`"=G9T`GIZ>`)^?GP"@H*``H:&A`**BH@"CHZ,`I*2D
M`*6EI0"FIJ8`IZ>G`*BHJ`"IJ:D`JJJJ`*NKJP"LK*P`K:VM`*ZNK@"OKZ\`
ML+"P`+&QL0"RLK(`L[.S`+2TM`"UM;4`MK:V`+>WMP"XN+@`N;FY`+JZN@"[
MN[L`O+R\`+V]O0"^OKX`O[^_`,#`P`#!P<$`PL+"`,/#PP#$Q,0`Q<7%`,;&
MQ@#'Q\<`R,C(`,G)R0#*RLH`R\O+`,S,S`#-S<T`SL[.`,_/SP#0T-``T='1
M`-+2T@#3T],`U-34`-75U0#6UM8`U]?7`-C8V`#9V=D`VMK:`-O;VP#<W-P`
MW=W=`-[>W@#?W]\`X.#@`.'AX0#BXN(`X^/C`.3DY`#EY>4`YN;F`.?GYP#H
MZ.@`Z>GI`.KJZ@#KZ^L`[.SL`.WM[0#N[NX`[^_O`/#P\`#Q\?$`\O+R`//S
M\P#T]/0`]?7U`/;V]@#W]_<`^/CX`/GY^0#Z^OH`^_O[`/S\_`#]_?T`_O[^
M`/___P`T-#0\/#P\/#P\/#P\/#P\/#P\/#P\/#PL#`0$!`0$!%RTU-34U-34
MU-34U-S4U-34U-34U-34U+0T400$!`0$9,SL]/3T_/3\]/3T_/3\]/ST_/S\
M]/3LQ#11400$!`1DQ.3L]/3T]/3T]/3T]/3T]/3T]/3T[.R\-%%1400$!&3$
MY.SL[.3L[.SDY.3D[.SD[.3L[.SLY+PT45%1400$9+SD[.RLC*S4Q)24G)2,
MC)24E)R<G.S<O#1145%1401DO-SD[.3$492L9.2D3#0L7,3,4;34Y-R\-%%1
M45%1462\W.3D[.3D481TY(QLI)QLC+QTK-3DW+PT!`0$!`0$9+S<Y.3LY.2\
M48S4U(RLS'3,W*11Q.3<O#0$!`0$!`1DO-SDY.3DY-R,?)RT?(2<;,SDO'3$
MY-RT-`0$!`0$!%R\W-SDY.3DU)RD7)2,S#R49,R\C%'<U+0T!`0$!`0$9+34
MW-S<Y-R,C*PLO+3,6L1DG&R4I-S4M#0$!`0$!`1<M-3<W.3<W'24U$RD](P\
MU'24=)Q,W,RT-`0$!`0$!&2TU-S<W.3<=%'T=(3LS&3D?&RDM&RDU+0T!`0$
M!`0$9+3,W-S,?(R$M/S,Q/STM/R\9,RLA%&\K#0$!`0$!`1<M,S4S(RDW-SL
M_/S\_/ST_.RT[*Q\E%&L-`0$!`0$!%RLS,QLG/3\_/S\_/S\_/S\_/S\Q)2,
M4:PT!`0$!`0$7*S$O'SD_/S\_/S\_/S\_/S\_/SLS*Q1K#0$!`0$!`1<K+1,
MQ/S\_.ST_/S\_/S\_/S\_/2\4<2L-`0$!`0$!%RLM$S4_/STM-S\_/S\_/S\
M_/S\S%',Q*0T!`0$!`0$7*S$I%'\_/RTG/3\_/S\_/S\_/244<S$I"P$!`0$
M!`1<I*11A.S\_,QDM.S\_/S\_/S\U&RLS+RD-`0$!`0$!%RD9'2\]/S\Q%&$
MG.3\_/S\_.2,4<S,Q*0T!`0$!`0$7*1LC.3T_/R<4<Q1E.S\_/S\O'3,S,2\
MG"P$!`0$!`1<I*QD7&2DI%&LS,1TE.3T_.11O,S,Q+R<-`0$!`0$!%RDM+R\
MC%%1Q,3,S*Q1?'R4;'R\S,3$O)PL!`0$!`0$7)R\Q,3$Q,3$Q,3$Q,1145%1
MO,3$Q,2TG#0$!`0$!`14G+3$Q,3$Q,3$Q,3$Q,3$Q,3$Q,3$O+2<+`0$!`0$
M!%2<O,3$O+R\O+R\O+R\O+R\O+R\O+R\M)PL!`0$!`0$7)RTQ+RTM+2TM+2T
MM+2TM+2TM+2TM+2LG"P$!`0$!`14A)2<G)24E)24E)24E)24E)24E)24E)2$
M)`0$!`0$!$147%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%0T!`0$!`0$````/P``
M`!\````/````!P````,````!`````````#\````_````/P```#\````_````
M/P```#\````_````/P```#\````_````/P```#\````_````/P```#\````_
M````/P```#\````_````/P```#\````_````/P```#\```$``@`0$````0`(
M`&@%```!`"`@```!``@`J`@```(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!.0C$P`````"XP*T@!````0SI<4$%27&)U:6QD7#4N
A.%Q005(M4&%C:V5R+3`N.3@P7&UY;&1R7'!A<BYP9&(`
